## Documentation and References

A complete reference guide - the API documentation - is available, which can be built locally using the gendocs.py script, in the pyjamas distribution.

There are also HOWTO Guides at the Pyjamas Wiki. These HOWTOs are written by users, for users, and will guide you through the process of setting up and using Pyjamas, including with your preferred web server framework (Django, Pylons, Web.py etc.)

## Pyjamas Book

An online version of the Pyjamas Book is available to read, and is in development. Contact lkcl@lkcl.net if there are any issues that you believe should be covered; if you find any errors; or if the book proves useful enough to be worth paying for. The Bookreader itself is a Pyjamas application which uses AJAX to load the contents as text files, and Wiki-like markup is used, on the browser, to generate the HTML displayed.

## Getting Started

Here are some resources to get you started with Pyjamas quickly:

- GettingStarted (a concise wiki article)
- Getting Started with pyjamas (if you prefer readable text over bulleted lists)
- Pyjamas Examples (demo applications and their source code)

## Mailing List

Pyjamas' (developer and user) mailing list is pyjamasdev@pyjs.org. You can use the Mail App (a Pyjamas application) to read the list archive on the web, or search for older mails in one of our Mailing List archives (Google Groups, Mail Archive, Nabble, Gmane).

Subscribe:
  Send an e-mail to pyjamasdev-subscribe@pyjs.org
Unsubscribe:
  Send an e-mail to pyjamasdev-unsubscribe@pyjs.org
Mail delivery off/on:
  Send an e-mail to pyjamasdev-nomail@pyjs.org to stop receiving mail from the list (make it quiet for some time). You will still be subscribed.
  Send an e-mail to pyjamasdev-mail@pyjs.org to re-enable receiving mail from the list.

Beware - as of 2012/01, the mailing list still doesn't handle CC's, so only use a single recipient (no "reply to all"), which must be the mailing list address: pyjamasdev@pyjs.org

## Before Asking For Help

Some other resources you may find worth consulting before you go and ask for help:

- Frequently asked questions
- Pyjamas' bug tracker
- Pyjamas source code (a Pyjamas application to browse the Git repository)